Place

Struct Place 

pub struct Place {
    pub base: PlaceBase,
    pub proj_start: u32,
    pub proj_len: u32,
}
A memory location that can be read from or written to.

A place represents a path to a memory location, consisting of a base (local variable or parameter) and zero or more projections (field access, array indexing).

Examples

  • xPlace { base: Local(0), proj_start: 0, proj_len: 0 }
  • arr[i]Place { base: Local(0), proj_start: 0, proj_len: 1 } with Index projection
  • point.xPlace { base: Local(0), proj_start: 0, proj_len: 1 } with Field projection
  • arr[i].xPlace { base: Local(0), proj_start: 0, proj_len: 2 } with Index then Field

Fields

base: PlaceBase

The base of the place - either a local slot or parameter slot

proj_start: u32

Start index into Cfg’s projections array

proj_len: u32

Number of projections

Implementations

Source

impl Place

pub const fn local(slot: u32) -> Self

Create a place for a local variable with no projections.

pub const fn param(slot: u32) -> Self

Create a place for a parameter with no projections.

pub const fn is_simple(&self) -> bool

Returns true if this place has no projections (is just a variable).

pub const fn as_local(&self) -> Option<u32>

Returns the local slot if this is a simple local place with no projections.

pub const fn as_param(&self) -> Option<u32>

Returns the param slot if this is a simple param place with no projections.