StructId

Struct StructId 

pub struct StructId(pub u32);
A unique identifier for a struct definition.

As of Phase 3 (ADR-0024), the inner value is a pool index into TypeInternPool, not a vector index into a separate struct definitions array.

Tuple Fields

0: u32

Implementations

Source

impl StructId

pub fn from_pool_index(pool_index: u32) -> StructId

Create a StructId from a pool index.

This is the primary way to create StructIds during Phase 3+. The pool index is the raw index into TypeInternPool.types.

pub fn pool_index(self) -> u32

Get the pool index for this struct.

This is the index into TypeInternPool.types.