pub struct Place {
pub base: PlaceBase,
pub proj_start: u32,
pub proj_len: u32,
}Expand description
A memory location that can be read from or written to.
A place represents a path to a memory location, consisting of a base (local variable or parameter) and zero or more projections (field access, array indexing).
Examples
x→Place { base: Local(0), proj_start: 0, proj_len: 0 }arr[i]→Place { base: Local(0), proj_start: 0, proj_len: 1 }withIndexprojectionpoint.x→Place { base: Local(0), proj_start: 0, proj_len: 1 }withFieldprojectionarr[i].x→Place { base: Local(0), proj_start: 0, proj_len: 2 }withIndexthenField
Fields
base: PlaceBaseThe base of the place - either a local slot or parameter slot
proj_start: u32Start index into Cfg’s projections array
proj_len: u32Number of projections
Implementations